#!/bin/sh

if [ -e /mnt/onboard/.kobo/manifest.md5sum ]; then 
	cd /mnt/onboard/.kobo
	md5sum -c manifest.md5sum
	if [ $? != 0 ]; then
		rm -rf manifest.md5sum
		exit 1;
	fi
	rm -rf manifest.md5sum
	cd /
fi

PLATFORM=freescale
if [ `dd if=/dev/mmcblk0 bs=512 skip=1024 count=1 | grep -c "HW CONFIG"` == 1 ]; then
	CPU=`ntx_hwconfig -s -p /dev/mmcblk0 CPU`
	PLATFORM=$CPU-ntx
fi

UBOOT=not_used
KERNEL=not_used

if [ $CPU ]; then
        PCB=`ntx_hwconfig -s -p /dev/mmcblk0 PCB`
        RAM=`ntx_hwconfig -s -p /dev/mmcblk0 RAMType`
	RAM_SIZE=`ntx_hwconfig -s -p /dev/mmcblk0 RamSize`
	RAM_SIZE=`echo $RAM_SIZE | awk '{print $RAM_SIZE-MB}'`
        NEW_UBOOT=/mnt/onboard/.kobo/upgrade/$PLATFORM/u-boot_mddr_$RAM_SIZE-$PCB-$RAM.bin
        NEW_KERNEL=/mnt/onboard/.kobo/upgrade/$PLATFORM/uImage-$PCB
        [ ! -e NEW_UBOOT ] && NEW_UBOOT=/mnt/onboard/.kobo/upgrade/$PLATFORM/u-boot_lpddr2_$RAM_SIZE-$PCB-$RAM.bin
	UBOOT=$NEW_UBOOT
	KERNEL=$NEW_KERNEL
fi

WAVEFORM=/mnt/onboard/.kobo/upgrade/waveform

[ $PLATFORM == freescale ] && UBOOT=/mnt/onboard/.kobo/upgrade/freescale/u-boot.bin
[ $PLATFORM == freescale ] && KERNEL=/mnt/onboard/.kobo/upgrade/freescale/uImage

echo your platform is $PLATFORM
echo $UBOOT
echo $KERNEL

/etc/init.d/upgrade-generic.sh $UBOOT $WAVEFORM $KERNEL mmcblk0

exit $?
